@@ -1,7 +1,7 @@
 /* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* vim: set ts=2 et sw=2 tw=80: */
 /*
-//@line 46 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 47 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
 */
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -98,6 +98,7 @@ const nsITimer = Components.interfaces.nsITimer;
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 Components.utils.import("resource://gre/modules/DownloadLastDir.jsm");
 Components.utils.import("resource://gre/modules/DownloadPaths.jsm");
+Components.utils.import("resource://gre/modules/DownloadUtils.jsm");
 
 /* ctor
  */
@@ -148,7 +149,7 @@ nsUnknownContentTypeDialog.prototype = {
   reallyShow: function() {
     try {
       var ir = this.mContext.QueryInterface(Components.interfaces.nsIInterfaceRequestor);
-      var dwi = ir.getInterface(Components.interfaces.nsIDOMWindowInternal);
+      var dwi = ir.getInterface(Components.interfaces.nsIDOMWindow);
       var ww = Components.classes["@mozilla.org/embedcomp/window-watcher;1"]
                          .getService(Components.interfaces.nsIWindowWatcher);
       this.mDialog = ww.openWindow(dwi,
@@ -238,7 +239,7 @@ nsUnknownContentTypeDialog.prototype = {
     var nsIFilePicker = Components.interfaces.nsIFilePicker;
     var picker = Components.classes["@mozilla.org/filepicker;1"].createInstance(nsIFilePicker);
     var windowTitle = bundle.GetStringFromName("saveDialogTitle");
-    var parent = aContext.QueryInterface(Components.interfaces.nsIInterfaceRequestor).getInterface(Components.interfaces.nsIDOMWindowInternal);
+    var parent = aContext.QueryInterface(Components.interfaces.nsIInterfaceRequestor).getInterface(Components.interfaces.nsIDOMWindow);
     picker.init(parent, windowTitle, nsIFilePicker.modeSave);
     picker.defaultString = aDefaultFile;
 
@@ -341,7 +342,7 @@ nsUnknownContentTypeDialog.prototype = {
 
     var createdFile = DownloadPaths.createNiceUniqueFile(aLocalFile);
 
-//@line 401 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 403 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
 
     return createdFile;
   },
@@ -415,7 +416,7 @@ nsUnknownContentTypeDialog.prototype = {
       // want users to be able to autodownload .exe files.
       var rememberChoice = this.dialogElement("rememberChoice");
 
-//@line 495 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 497 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
       if (shouldntRememberChoice) {
         rememberChoice.checked = false;
         rememberChoice.disabled = true;
@@ -533,8 +534,16 @@ nsUnknownContentTypeDialog.prototype = {
       else
         typeString = mimeInfo.MIMEType;
     }
-
-    type.value = typeString;
+    if (this.mLauncher.contentLength) {
+      let [size, unit] = DownloadUtils.
+                         convertByteUnits(this.mLauncher.contentLength);
+      type.value = this.dialogElement("strings")
+                       .getFormattedString("fileSizeWithType", 
+                                           [typeString, size, unit]);
+    }
+    else {
+      type.value = typeString;
+    }
   },
 
   _blurred: false,
@@ -555,12 +564,12 @@ nsUnknownContentTypeDialog.prototype = {
   // Returns true if opening the default application makes sense.
   openWithDefaultOK: function() {
     // The checking is different on Windows...
-//@line 645 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 655 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
     // On other platforms, default is Ok if there is a default app.
     // Note that nsIMIMEInfo providers need to ensure that this holds true
     // on each platform.
     return this.mLauncher.MIMEInfo.hasDefaultHandler;
-//@line 650 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 660 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
   },
 
   // Set "default" application description field.
@@ -581,9 +590,9 @@ nsUnknownContentTypeDialog.prototype = {
 
   // getPath:
   getPath: function (aFile) {
-//@line 673 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 683 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
     return aFile.path;
-//@line 675 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 685 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
   },
 
   // initAppAndSaveToDiskValues:
@@ -813,7 +822,7 @@ nsUnknownContentTypeDialog.prototype = {
         // for the file to be saved to to pass to |saveToDisk| - otherwise
         // we must ask the user to pick a save name.
 
-//@line 918 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 928 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
 
         // see @notify
         // we cannot use opener's setTimeout, see bug 420405
@@ -868,13 +877,13 @@ nsUnknownContentTypeDialog.prototype = {
   // Retrieve the pretty description from the file
   getFileDisplayName: function getFileDisplayName(file)
   {
-//@line 986 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 996 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
     return file.leafName;
   },
 
   // chooseApp:  Open file picker and prompt user for application.
   chooseApp: function() {
-//@line 1034 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 1044 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
     var nsIFilePicker = Components.interfaces.nsIFilePicker;
     var fp = Components.classes["@mozilla.org/filepicker;1"]
                        .createInstance(nsIFilePicker);
@@ -891,7 +900,7 @@ nsUnknownContentTypeDialog.prototype = {
                    createInstance(Components.interfaces.nsILocalHandlerApp);
       localHandlerApp.executable = fp.file;
       this.chosenApp = localHandlerApp;
-//@line 1051 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 1061 "/builds/slave/m-beta-lnx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
 
       // Show the "handler" menulist since we have a (user-specified)
       // application now.
